@@ -669,7 +669,7 @@ mod tests {
             CircuitBuilder::new()
                 .with_circuit_id("abcde-12345".into())
                 .with_authorization_type(&AuthorizationType::Trust)
-                .with_members(&["node_1".to_string(), "node_2".to_string()])
+                .with_members(&nodes)
                 .with_roster(&[service])
                 .with_persistence(&PersistenceType::Any)
                 .with_durability(&DurabilityType::NoDurability)
@@ -707,7 +707,7 @@ mod tests {
             CircuitBuilder::new()
                 .with_circuit_id("efghi-56789")
                 .with_authorization_type(&AuthorizationType::Trust)
-                .with_members(&["node_3".to_string(), "node_4".to_string()])
+                .with_members(&nodes)
                 .with_roster(&[service])
                 .with_persistence(&PersistenceType::Any)
                 .with_durability(&DurabilityType::NoDurability)
@@ -744,7 +744,7 @@ mod tests {
             CircuitBuilder::new()
                 .with_circuit_id("efghi-12345")
                 .with_authorization_type(&AuthorizationType::Trust)
-                .with_members(&["node_5".to_string(), "node_6".to_string()])
+                .with_members(&nodes)
                 .with_roster(&[service])
                 .with_persistence(&PersistenceType::Any)
                 .with_durability(&DurabilityType::NoDurability)
