@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,7 +12,5 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-pub(in super::super) mod circuits;
-pub(in super::super) mod circuits_circuit_id;
-pub(in super::super) mod proposals;
-pub(in super::super) mod proposals_circuit_id;
+pub mod v1;
+pub mod v2;
