@@ -20,6 +20,9 @@ pub mod trust_v1;
 use std::fmt;
 use std::sync::{Arc, Mutex};
 
+#[cfg(feature = "challenge-authorization")]
+use crate::public_key::PublicKey;
+
 #[cfg(feature = "challenge-authorization")]
 use self::challenge_v1::{
     ChallengeAuthorizationLocalAction, ChallengeAuthorizationLocalState,
@@ -41,7 +44,7 @@ pub enum Identity {
     },
     #[cfg(feature = "challenge-authorization")]
     Challenge {
-        public_key: Vec<u8>,
+        public_key: PublicKey,
     },
 }
 
@@ -245,7 +248,7 @@ impl fmt::Display for AuthorizationActionError {
                     start, action
                 )
             }
-            AuthorizationActionError::InternalError(msg) => f.write_str(&msg),
+            AuthorizationActionError::InternalError(msg) => f.write_str(msg),
         }
     }
 }
