@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -141,18 +141,18 @@ impl RegistryReader for UnifiedRegistry {
         self.list_nodes(predicates).map(|iter| iter.count() as u32)
     }
 
-    fn fetch_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
+    fn get_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
         // Get node from all read-only sources
         Ok(self
             .external_sources
             .iter()
-            .map(|registry| registry.fetch_node(identity))
+            .map(|registry| registry.get_node(identity))
             // Reverse the sources, so lowest precedence is first
             .rev()
             // Get node from the internal source and add it to the end, since it has highest
             // precedence
-            .chain(std::iter::once(self.internal_source.fetch_node(identity)))
-            // Log any errors from the `fetch_node` calls and ignore the failing registries
+            .chain(std::iter::once(self.internal_source.get_node(identity)))
+            // Log any errors from the `get_node` calls and ignore the failing registries
             .filter_map(|res| {
                 res.map_err(|err| debug!("Failed to fetch node from source registry: {}", err))
                     .ok()
@@ -175,11 +175,37 @@ impl RegistryReader for UnifiedRegistry {
                 }
             }))
     }
+
+    fn has_node(&self, identity: &str) -> Result<bool, RegistryError> {
+        Ok(self
+            .internal_source
+            .has_node(identity)
+            .unwrap_or_else(|err| {
+                debug!(
+                    "Failed to check for existence of node in source registry: {}",
+                    err
+                );
+                false
+            })
+            || self.external_sources.iter().any(|source| {
+                source.has_node(identity).unwrap_or_else(|err| {
+                    debug!(
+                        "Failed to check for existence of node in source registry: {}",
+                        err
+                    );
+                    false
+                })
+            }))
+    }
 }
 
 impl RegistryWriter for UnifiedRegistry {
-    fn insert_node(&self, node: Node) -> Result<(), RegistryError> {
-        self.internal_source.insert_node(node)
+    fn add_node(&self, node: Node) -> Result<(), RegistryError> {
+        self.internal_source.add_node(node)
+    }
+
+    fn update_node(&self, node: Node) -> Result<(), RegistryError> {
+        self.internal_source.update_node(node)
     }
 
     fn delete_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
@@ -208,6 +234,7 @@ mod test {
     use std::sync::{Arc, Mutex};
 
     use super::*;
+    use crate::error::InvalidStateError;
 
     fn new_node(id: &str, endpoint: &str, metadata: &[(&str, &str)]) -> Node {
         let mut builder = Node::builder(id).with_endpoint(endpoint).with_key("abcd");
@@ -236,17 +263,11 @@ mod test {
         let node3 = new_node("node1", "endpoint3", &[("meta_c", "val_c")]);
 
         let writeable = MemRegistry::default();
-        writeable
-            .insert_node(node1)
-            .expect("Unable to insert node1");
-        writeable
-            .insert_node(node2)
-            .expect("Unable to insert node2");
+        writeable.add_node(node1).expect("Unable to insert node1");
+        writeable.add_node(node2).expect("Unable to insert node2");
 
         let readable = MemRegistry::default();
-        writeable
-            .insert_node(node3)
-            .expect("Unable to insert node3");
+        writeable.add_node(node3).expect("Unable to insert node3");
 
         let unified = UnifiedRegistry::new(Box::new(writeable), vec![Box::new(readable)]);
 
@@ -273,15 +294,11 @@ mod test {
         );
 
         let writeable = MemRegistry::default();
-        writeable
-            .insert_node(node1)
-            .expect("Unable to insert node1");
-        writeable
-            .insert_node(node2)
-            .expect("Unable to insert node2");
+        writeable.add_node(node1).expect("Unable to insert node1");
+        writeable.add_node(node2).expect("Unable to insert node2");
 
         let readable = MemRegistry::default();
-        readable.insert_node(node3).expect("Unable to insert node3");
+        readable.add_node(node3).expect("Unable to insert node3");
 
         let unified = UnifiedRegistry::new(Box::new(writeable), vec![Box::new(readable)]);
 
@@ -298,19 +315,19 @@ mod test {
 
     /// Verify that a node is fetched from a read-only source if it only exists there.
     #[test]
-    fn fetch_node_read_only() {
+    fn get_node_read_only() {
         let node = new_node("node1", "endpoint1", &[("meta_a", "val_a")]);
 
         let readable = MemRegistry::default();
         readable
-            .insert_node(node.clone())
+            .add_node(node.clone())
             .expect("Unable to insert node");
 
         let unified =
             UnifiedRegistry::new(Box::new(MemRegistry::default()), vec![Box::new(readable)]);
 
         let retreived_node = unified
-            .fetch_node("node1")
+            .get_node("node1")
             .expect("Unable to fetch node")
             .expect("Node not found");
 
@@ -319,19 +336,19 @@ mod test {
 
     /// Verify that a node is fetched from the internal source if it only exists there.
     #[test]
-    fn fetch_node_internal() {
+    fn get_node_internal() {
         let node = new_node("node1", "endpoint1", &[("meta_a", "val_a")]);
 
         let writable = MemRegistry::default();
         writable
-            .insert_node(node.clone())
+            .add_node(node.clone())
             .expect("Unable to insert node");
 
         let unified =
             UnifiedRegistry::new(Box::new(writable), vec![Box::new(MemRegistry::default())]);
 
         let retreived_node = unified
-            .fetch_node("node1")
+            .get_node("node1")
             .expect("Unable to fetch node")
             .expect("Node not found");
 
@@ -347,7 +364,7 @@ mod test {
     /// 3. Fetch the node and verify that it has the correct data (endpoint from highest-precedence
     ///    registry, metadata merged from all registries).
     #[test]
-    fn fetch_node_read_only_precedence() {
+    fn get_node_read_only_precedence() {
         let high_precedence_node = new_node("node1", "endpoint1", &[("meta_a", "val_a")]);
         let med_precedence_node = new_node("node1", "endpoint2", &[("meta_b", "val_b")]);
         let low_precedence_node = new_node("node1", "endpoint3", &[("meta_a", "val_c")]);
@@ -359,17 +376,17 @@ mod test {
 
         let high_precedence_readable = MemRegistry::default();
         high_precedence_readable
-            .insert_node(high_precedence_node)
+            .add_node(high_precedence_node)
             .expect("Unable to insert high-precedence node");
 
         let med_precedence_readable = MemRegistry::default();
         med_precedence_readable
-            .insert_node(med_precedence_node)
+            .add_node(med_precedence_node)
             .expect("Unable to insert medium-precedence node");
 
         let low_precedence_readable = MemRegistry::default();
         low_precedence_readable
-            .insert_node(low_precedence_node)
+            .add_node(low_precedence_node)
             .expect("Unable to insert low-precedence node");
 
         let unified = UnifiedRegistry::new(
@@ -382,7 +399,7 @@ mod test {
         );
 
         let retreived_node = unified
-            .fetch_node("node1")
+            .get_node("node1")
             .expect("Unable to fetch node")
             .expect("Node not found");
 
@@ -398,7 +415,7 @@ mod test {
     /// 3. Fetch the node and verify that it has the correct data (endpoints from internal registry,
     ///    metadata merged from all sources).
     #[test]
-    fn fetch_node_internal_precedence() {
+    fn get_node_internal_precedence() {
         let high_precedence_node = new_node("node1", "endpoint1", &[("meta_a", "val_a")]);
         let med_precedence_node = new_node("node1", "endpoint2", &[("meta_b", "val_b")]);
         let low_precedence_node = new_node("node1", "endpoint3", &[("meta_a", "val_c")]);
@@ -410,17 +427,17 @@ mod test {
 
         let writable = MemRegistry::default();
         writable
-            .insert_node(high_precedence_node)
+            .add_node(high_precedence_node)
             .expect("Unable to insert high-precedence node");
 
         let med_precedence_readable = MemRegistry::default();
         med_precedence_readable
-            .insert_node(med_precedence_node)
+            .add_node(med_precedence_node)
             .expect("Unable to insert medium-precedence node");
 
         let low_precedence_readable = MemRegistry::default();
         low_precedence_readable
-            .insert_node(low_precedence_node)
+            .add_node(low_precedence_node)
             .expect("Unable to insert low-precedence node");
 
         let unified = UnifiedRegistry::new(
@@ -432,13 +449,42 @@ mod test {
         );
 
         let retreived_node = unified
-            .fetch_node("node1")
+            .get_node("node1")
             .expect("Unable to fetch node")
             .expect("Node not found");
 
         assert_eq!(expected_node, retreived_node);
     }
 
+    /// Verify that `has_node` properly determines if a node exists in any of the sources.
+    #[test]
+    fn has_node() {
+        let node1 = new_node("node1", "endpoint1", &[]);
+        let node2 = new_node("node2", "endpoint2", &[]);
+
+        let writable = MemRegistry::default();
+        writable
+            .add_node(node1.clone())
+            .expect("Unable to insert node");
+
+        let readable = MemRegistry::default();
+        readable
+            .add_node(node2.clone())
+            .expect("Unable to insert node");
+
+        let unified = UnifiedRegistry::new(Box::new(writable), vec![Box::new(readable)]);
+
+        assert!(unified
+            .has_node(&node1.identity)
+            .expect("Failed to check if node1 exists"));
+        assert!(unified
+            .has_node(&node2.identity)
+            .expect("Failed to check if node2 exists"));
+        assert!(!unified
+            .has_node("NodeNotInRegistry")
+            .expect("Failed to check for non-existent node"));
+    }
+
     /// Verify that listed nodes are properly returned based on precedence and that metadata is
     /// correctly merged.
     ///
@@ -482,20 +528,20 @@ mod test {
 
         let writable = MemRegistry::default();
         writable
-            .insert_node(node1_internal)
+            .add_node(node1_internal)
             .expect("Unable to insert internal node1");
 
         let readable_high = MemRegistry::default();
         readable_high
-            .insert_node(node1_read_only)
+            .add_node(node1_read_only)
             .expect("Unable to insert read-only node1");
         readable_high
-            .insert_node(node2_high)
+            .add_node(node2_high)
             .expect("Unable to insert high-precedence node2");
 
         let readable_low = MemRegistry::default();
         readable_low
-            .insert_node(node2_low)
+            .add_node(node2_low)
             .expect("Unable to insert low-precedence node2");
 
         let unified = UnifiedRegistry::new(
@@ -533,14 +579,12 @@ mod test {
 
         let writeable = MemRegistry::default();
         writeable
-            .insert_node(node1.clone())
+            .add_node(node1.clone())
             .expect("Unable to insert node1");
-        writeable
-            .insert_node(node2)
-            .expect("Unable to insert node2");
+        writeable.add_node(node2).expect("Unable to insert node2");
 
         let readable = MemRegistry::default();
-        readable.insert_node(node3).expect("Unable to insert node3");
+        readable.add_node(node3).expect("Unable to insert node3");
 
         let unified = UnifiedRegistry::new(Box::new(writeable), vec![Box::new(readable)]);
 
@@ -566,7 +610,7 @@ mod test {
 
         let readable = MemRegistry::default();
         readable
-            .insert_node(node2.clone())
+            .add_node(node2.clone())
             .expect("Unable to insert node2 into read-only registry");
 
         let unified = UnifiedRegistry::new(
@@ -576,7 +620,7 @@ mod test {
 
         // Verify node1 is only added to writeable
         unified
-            .insert_node(node1.clone())
+            .add_node(node1.clone())
             .expect("Unable to add node1");
         assert!(unified
             .has_node(&node1.identity)
@@ -638,7 +682,7 @@ mod test {
             self.list_nodes(predicates).map(|iter| iter.count() as u32)
         }
 
-        fn fetch_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
+        fn get_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
             Ok(self
                 .nodes
                 .lock()
@@ -649,7 +693,7 @@ mod test {
     }
 
     impl RegistryWriter for MemRegistry {
-        fn insert_node(&self, node: Node) -> Result<(), RegistryError> {
+        fn add_node(&self, node: Node) -> Result<(), RegistryError> {
             self.nodes
                 .lock()
                 .expect("mem registry lock was poisoned")
@@ -657,6 +701,22 @@ mod test {
             Ok(())
         }
 
+        fn update_node(&self, node: Node) -> Result<(), RegistryError> {
+            let mut inner = self.nodes.lock().expect("mem registry lock was poisoned");
+
+            if inner.contains_key(&node.identity) {
+                inner.insert(node.identity.clone(), node);
+                Ok(())
+            } else {
+                Err(RegistryError::InvalidStateError(
+                    InvalidStateError::with_message(format!(
+                        "Node does not exist in the registry: {}",
+                        node.identity
+                    )),
+                ))
+            }
+        }
+
         fn delete_node(&self, identity: &str) -> Result<Option<Node>, RegistryError> {
             Ok(self
                 .nodes
