@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,5 +14,6 @@
 
 //! This module will contain components that will be used to support different threading models
 
-pub mod error;
-pub mod pacemaker;
+pub(crate) mod error;
+pub mod lifecycle;
+pub(crate) mod pacemaker;
